@@ -70,15 +70,11 @@ class ASTROMER:
         mask   = Input(shape=(self.maxlen, 1),
                     batch_size=None,
                     name='mask')
-        length = Input(shape=(self.maxlen,),
-                    batch_size=None,
-                    dtype=tf.int32,
-                    name='length')
+
 
         placeholder = {'input':serie,
                     'mask_in':mask,
-                    'times':times,
-                    'length':length}
+                    'times':times}
 
         encoder = Encoder(self.num_layers,
                     self.d_model,
